==> qastools_1.1.0.orig.tar.xz: qastools-v1.1.0/shared/src/wdg/sliders_pad.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_focus_info.hpp"
#include <QWidget>
#include <vector>

// Forward declaration
namespace dpe
{
class Image_Allocator;
}
namespace Wdg
{
class Sliders_Pad_Data;
class Sliders_Pad_Data_Group;
class Sliders_Pad_Data_Column;
class Sliders_Pad_Header_Data;
class Sliders_Pad_Header;
class Sliders_Pad_Footer;
class Sliders_Pad_Style;
class Pad_Proxies_Group;
class DS_Widget_Style_Db;
} // namespace Wdg

namespace Wdg
{

/// @brief Sliders_Pad
///
class Sliders_Pad : public QWidget
{
  Q_OBJECT

  // Public methods
  public:
  // -- Construction

  Sliders_Pad ( QWidget * parent_n = nullptr,
                ::dpe::Image_Allocator * isg_alloc_n = nullptr );

  ~Sliders_Pad ();

  // -- Proxies groups list

  const ::std::vector< Pad_Proxies_Group * > &
  proxies_groups () const
  {
    return _proxies_groups;
  }

  void
  set_proxies_groups ( const ::std::vector< Pad_Proxies_Group * > & list_n );

  void
  clear_proxies_groups ();

  // -- Proxies group access

  ::std::size_t
  num_proxies_groups () const
  {
    return _proxies_groups.size ();
  }

  Pad_Proxies_Group *
  proxies_group ( ::std::size_t idx_n )
  {
    return _proxies_groups[ idx_n ];
  }

  // -- Widget style database

  const ::Wdg::DS_Widget_Style_Db *
  wdg_style_db () const
  {
    return _wdg_style_db;
  }

  void
  set_wdg_style_db ( const ::Wdg::DS_Widget_Style_Db * style_db_n );

  // -- Image_Set_Group allocator

  void
  set_image_alloc ( ::dpe::Image_Allocator * alloc_n );

  ::dpe::Image_Allocator *
  image_alloc () const
  {
    return _image_alloc;
  }

  // -- Show footer

  bool
  footer_visible () const;

  void
  set_footer_visible ( bool flag_n );

  // -- Wheel degrees

  ::std::size_t
  wheel_degrees () const
  {
    return _wheel_degrees;
  }

  void
  set_wheel_degrees ( ::std::size_t delta_n );

  // Widgets

  QWidget *
  header ();

  QWidget *
  footer ();

  ::Wdg::Sliders_Pad_Header *
  header_cast ();

  ::Wdg::Sliders_Pad_Footer *
  footer_cast ();

  ::Wdg::Sliders_Pad_Header_Data *
  header_data ();

  ::Wdg::Sliders_Pad_Header_Data *
  footer_data ();

  ::std::size_t
  num_widgets () const
  {
    return _widgets.size ();
  }

  QWidget *
  widget ( ::std::size_t idx_n )
  {
    return _widgets[ idx_n ];
  }

  // -- Focus info

  const Pad_Focus_Info &
  focus_info () const
  {
    return _focus_info;
  }

  /// @brief Event handler reimplementation
  bool
  event ( QEvent * event_n ) override;

  // -- Public signals
  Q_SIGNAL
  void
  sig_focus_changed ();

  Q_SIGNAL
  void
  sig_footer_label_selected ( unsigned int group_idx_n,
                              unsigned int column_idx_n );

  // -- Public slots
  Q_SLOT
  bool
  set_focus_proxy ( unsigned int group_idx_n );

  Q_SLOT
  bool
  set_focus_proxy ( unsigned int group_idx_n,
                    unsigned int column_idx_n,
                    unsigned int row_idx_n );

  // Protected methods
  protected:
  void
  clear_widgets ();

  void
  create_widgets ();

  // Event methods

  void
  resizeEvent ( QResizeEvent * event ) override;

  void
  paintEvent ( QPaintEvent * event ) override;

  // Protected slots
  protected:
  Q_SLOT
  void
  header_label_selected ( unsigned int group_idx_n, unsigned int column_idx_n );

  Q_SLOT
  void
  footer_label_selected ( unsigned int group_idx_n, unsigned int column_idx_n );

  // Private methods
  private:
  void
  update_colors ();

  // Private attributes
  private:
  ::std::vector< ::Wdg::Pad_Proxies_Group * > _proxies_groups;
  ::Wdg::Sliders_Pad_Data * _sp_data;

  ::std::vector< QWidget * > _widgets;
  ::Wdg::Pad_Focus_Info _focus_info;

  bool _update_decoration = true;

  ::std::size_t _wheel_degrees = 720;

  ::Wdg::Sliders_Pad_Style * _sp_style; // Paints decoration graphics
  const ::Wdg::DS_Widget_Style_Db * _wdg_style_db = nullptr;
  ::dpe::Image_Allocator * _image_alloc = nullptr;
};

} // namespace Wdg

==> qastools_1.2.0.orig.tar.xz: qastools-v1.2.0/shared/src/wdg/sliders_pad.hpp <==
/// QasTools: Desktop toolset for the Linux sound system ALSA.
/// \copyright See COPYING file.

#pragma once

#include "wdg/pad_focus_info.hpp"
#include <QWidget>
#include <vector>

// Forward declaration
namespace dpe
{
class Image_Allocator;
}
namespace Wdg
{
class Sliders_Pad_Data;
class Sliders_Pad_Data_Group;
class Sliders_Pad_Data_Column;
class Sliders_Pad_Header_Data;
class Sliders_Pad_Header;
class Sliders_Pad_Footer;
class Sliders_Pad_Style;
class Pad_Proxies_Group;
} // namespace Wdg
namespace Wdg::DS
{
class Widget_Style_Db;
}

namespace Wdg
{

/// @brief Sliders_Pad
///
class Sliders_Pad : public QWidget
{
  Q_OBJECT

  public:
  // -- Construction

  Sliders_Pad ( const Wdg::DS::Widget_Style_Db * wdg_style_db_n,
                dpe::Image_Allocator * image_alloc_n,
                QWidget * parent_n = nullptr );

  ~Sliders_Pad ();

  // -- Proxies groups list

  const std::vector< Pad_Proxies_Group * > &
  proxies_groups () const
  {
    return _proxies_groups;
  }

  void
  set_proxies_groups ( const std::vector< Pad_Proxies_Group * > & list_n );

  void
  clear_proxies_groups ();

  // -- Proxies group access

  std::size_t
  num_proxies_groups () const
  {
    return _proxies_groups.size ();
  }

  Pad_Proxies_Group *
  proxies_group ( std::size_t idx_n )
  {
    return _proxies_groups[ idx_n ];
  }

  // -- Widget style database

  const Wdg::DS::Widget_Style_Db *
  wdg_style_db () const
  {
    return _wdg_style_db;
  }

  // -- Image_Set_Group allocator

  dpe::Image_Allocator *
  image_alloc () const
  {
    return _image_alloc;
  }

  // -- Show footer

  bool
  footer_visible () const;

  void
  set_footer_visible ( bool flag_n );

  // -- Wheel degrees

  std::size_t
  wheel_degrees () const
  {
    return _wheel_degrees;
  }

  void
  set_wheel_degrees ( std::size_t delta_n );

  // Widgets

  QWidget *
  header ();

  QWidget *
  footer ();

  Wdg::Sliders_Pad_Header *
  header_cast ();

  Wdg::Sliders_Pad_Footer *
  footer_cast ();

  Wdg::Sliders_Pad_Header_Data *
  header_data ();

  Wdg::Sliders_Pad_Header_Data *
  footer_data ();

  std::size_t
  num_widgets () const
  {
    return _widgets.size ();
  }

  QWidget *
  widget ( std::size_t idx_n )
  {
    return _widgets[ idx_n ];
  }

  // -- Focus info

  const Pad_Focus_Info &
  focus_info () const
  {
    return _focus_info;
  }

  /// @brief Event handler reimplementation
  bool
  event ( QEvent * event_n ) override;

  // -- Public signals
  Q_SIGNAL
  void
  sig_focus_changed ();

  Q_SIGNAL
  void
  sig_footer_label_selected ( unsigned int group_idx_n,
                              unsigned int column_idx_n );

  // -- Public slots
  Q_SLOT
  bool
  set_focus_proxy ( unsigned int group_idx_n );

  Q_SLOT
  bool
  set_focus_proxy ( unsigned int group_idx_n,
                    unsigned int column_idx_n,
                    unsigned int row_idx_n );

  protected:
  // -- Protected methods

  void
  clear_widgets ();

  void
  create_widgets ();

  // Event methods

  void
  changeEvent ( QEvent * event_n ) override;

  void
  resizeEvent ( QResizeEvent * event ) override;

  void
  paintEvent ( QPaintEvent * event ) override;

  protected:
  // -- Protected slots

  Q_SLOT
  void
  header_label_selected ( unsigned int group_idx_n, unsigned int column_idx_n );

  Q_SLOT
  void
  footer_label_selected ( unsigned int group_idx_n, unsigned int column_idx_n );

  Q_SLOT
  void
  style_palette_changed ( unsigned int style_id_n );

  private:
  // -- Private methods

  void
  update_colors ();

  private:
  // -- Attributes
  std::vector< Wdg::Pad_Proxies_Group * > _proxies_groups;
  Wdg::Sliders_Pad_Data * _sp_data;

  std::vector< QWidget * > _widgets;
  Wdg::Pad_Focus_Info _focus_info;

  bool _update_decoration = true;

  std::size_t _wheel_degrees = 720;

  Wdg::Sliders_Pad_Style * _sp_style; // Paints decoration graphics
  const Wdg::DS::Widget_Style_Db * _wdg_style_db = nullptr;
  dpe::Image_Allocator * _image_alloc = nullptr;
};

} // namespace Wdg
